<?php
/**
 * VuFind Action Helper - New Items Support Methods
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library 2020.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Controller_Plugins
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Page
 */
namespace finc\Controller\Plugin;

use Zend\Config\Config;
use Zend\Mvc\Controller\Plugin\AbstractPlugin;

/**
 * Zend action helper to perform new items-related actions
 *
 * @category VuFind
 * @package  Controller_Plugins
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Page
 */
class NewItems extends \VuFind\Controller\Plugin\NewItems
{
    /**
     * Main Configuration
     *
     * @var null|Config
     */
    protected $mainConfig;

    /**
     * Constructor
     *
     * @param Config $searchConfig Configuration
     * @param Config $mainConfig Configuration
     */
    public function __construct(Config $searchConfig, Config $mainConfig)
    {
        $this->config = $searchConfig;
        $this->mainConfig = $mainConfig;
    }

    /**
     * Get a Solr filter to limit to the specified number of days.
     *
     * @param int $range Days to search
     *
     * @return string
     */
    public function getSolrFilter($range)
    {
        $field = 'first_indexed';
        if (!empty($isilPrefix = $this->mainConfig->CustomIndex->indexExtension)) {
            $field = "{$isilPrefix}_date";
        }
        return "$field:[NOW-{$range}DAY TO NOW]";
    }
}
