<?php
/**
 * Cover image router
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2016.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Cover_Generator
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/configuration:external_content Wiki
 */
namespace finc\Cover;

use finc\Cover\Loader as CoverLoader;
use VuFind\RecordDriver\AbstractBase as RecordDriver;

/**
 * Cover image router
 *
 * @deprecated backport of VuFind 7 core version, remove on upgrade
 * @category VuFind
 * @package  Cover_Generator
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/configuration:external_content Wiki
 */
// Add "extends \VuFind\Cover\Router" to prevent "Whoops" error - #18898 - HR
class Router extends \VuFind\Cover\Router implements \Zend\Log\LoggerAwareInterface
{
    use \VuFind\Log\LoggerAwareTrait;

    /**
     * Base URL for dynamic cover images.
     *
     * @var string
     */
    protected $dynamicUrl;

    /**
     * Cover loader
     *
     * @var CoverLoader
     */
    protected $coverLoader;

    /**
     * Constructor
     *
     * @param string      $url         Base URL for dynamic cover images.
     * @param CoverLoader $coverLoader Cover loader
     */
    public function __construct($url, CoverLoader $coverLoader)
    {
        $this->dynamicUrl = $url;
        $this->coverLoader = $coverLoader;
    }

    /**
     * This is an adaptation of the VuFind Version to fit the current (VF5) state
     *
     * Generate a thumbnail URL (return false if unsupported).
     *
     * @param RecordDriver $driver Record driver
     * @param string       $size   Size of thumbnail (small, medium or large --
     * small is default).
     *
     * @return string|bool
     */
    public function getUrl(RecordDriver $driver, $size = 'small',
        $resolveDynamic = true, $testLoadImage = false
    )
    {
        // Try to build thumbnail:
        $thumb = $driver->tryMethod('getThumbnail', [$size]);

        // No thumbnail?  Return false:
        if (empty($thumb)) {
            return false;
        }

        // Array?  It's parameters to send to the cover generator:
        if (is_array($thumb)) {
            if (!$resolveDynamic) {
                return null;
            }
            if ($testLoadImage) {
                $this->coverLoader->loadImage(array_merge($thumb, ['size' => $size]));
                if ($this->coverLoader->hasLoadedUnavailable()) {
                    return false;
                }
            }
            return $this->dynamicUrl . '?' . http_build_query($thumb);
        }

        // Default case -- return fixed string:
        return $thumb;
    }
}
