<?php
/**
 * HierarchyTree tab
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2010.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  RecordTabs
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:record_tabs Wiki
 */
namespace finc\RecordTab;

/**
 * HierarchyTree tab
 *
 * @category VuFind
 * @package  RecordTabs
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:record_tabs Wiki
 */
class HierarchyTree extends \VuFind\RecordTab\HierarchyTree
{
    /**
     * Tree data
     *
     * @var array
     */
    protected $treeList = null;

    public function getDescription()
    {
        if ($this->driver->isCollection()) return 'collection_hierarchy_tree_tab';
        else return 'hierarchy_tree';
    }

    public function isActive()
    {
        $trees = $this->getTreeList();
        if (empty($trees)) {
            return false;
        }
        foreach ($trees as $key => $value) {
            if ($key !== $this->driver->getUniqueID()) {
                return true;
            }
        }
        if ($this->driver->getChildRecordCount() > 0) {
            return true;
        }
        return false;
    }

    /**
     * Can this tab be loaded via AJAX?
     *
     * @return bool
     */
    public function supportsAjax()
    {
        // No, special width adjustment needed.
        return true;
    }
}
