<?php
/**
 * Config SearchSpecsReader Test Class
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2010.
 * Copyright (C) Leipzig University Library 2020.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category Finc
 * @package  Tests
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:testing:unit_tests Wiki
 */
namespace fincTest\Config;

use Symfony\Component\Yaml\Yaml;
use VuFind\Config\Locator;
use VuFind\Config\SearchSpecsReader;

/**
 * Config SearchSpecsReader Test Class
 *
 * @category VuFind
 * @package  Tests
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:testing:unit_tests Wiki
 */
class SearchSpecsReaderTest extends \VuFindTest\Config\SearchSpecsReaderTest
{
    /**
     * Name of default yaml name to test.
     *
     * @var string
     */
    protected static $defaultYamlName = 'searchspecs.yaml';

    /**
     * YamlReader for SearchSpecs files.
     *
     * @var SearchSpecsReader
     */
    protected static $reader;

    /**
     * Path to symlinks and expected searchspecs result.
     *
     * @var string
     */
    protected $basePathToFixtures;

    /**
     * Path to local logging / printing.
     *
     * @var string
     */
    protected $basePathToLogging;

    /**
     * Override standard setup method.
     *
     * @return void
     */
    public static function setUpBeforeClass()
    {
        // Don't create test files, use existing.

        // CAUTION, DONT DELETE REAL CONFIG FILES!
        self::$filesToDelete = [];
        self::$reader = new SearchSpecsReader();
    }

    /**
     * Test @parent_yaml directive.
     *
     * @return void
     */
    public function testParentYaml()
    {
        if (self::$writeFailed) {
            $this->markTestSkipped('Could not write test configurations.');
        }
        $this->basePathToFixtures = __DIR__ . "/../../../../fixtures/configs/yaml/searchspecs";
        $this->basePathToLogging  = __DIR__ . "/log/";

        /* check live finc searchspecs.yaml is equal to old /desired live searchspecs.yaml */
        $this->isEcpectedSpec('local');

        /* check alpha finc searchspecs.yaml is equal to old /desired alpha searchspecs.yaml */
        $this->isEcpectedSpec('local/alpha');
    }

    /**
     * @param string $environment
     * @param bool $printResult
     * @throws \ReflectionException
     */
    protected function isEcpectedSpec(string $environment, bool $printResult = false): void
    {
        $basePathAppendix   = "config/vufind/" . self::$defaultYamlName;

        $vufindYaml     = "$this->basePathToFixtures/$basePathAppendix";
        $currentEnvYaml = "$this->basePathToFixtures/$environment/$basePathAppendix";
        $expectedYaml   = "$this->basePathToFixtures/result/$environment/" . self::$defaultYamlName;

        $resultArray    = $this->callMethod(self::$reader, 'getFromPaths', [$vufindYaml, $currentEnvYaml]);
        $expectedArray  = $this->callMethod(self::$reader, 'getFromPaths', [$expectedYaml]);

        if ($printResult) {
            file_put_contents("$this->basePathToLogging/input_reverse.yaml", Yaml::dump($resultArray, 4, 2));
        }

        $this->assertEquals(
            $resultArray,
            $expectedArray
        );
    }
}
